@@ -4,6 +4,7 @@ from django.utils.translation import ugettext_lazy as _
 from invitations.adapters import get_invitations_adapter
 from invitations.exceptions import (AlreadyAccepted, AlreadyInvited,
                                     UserRegisteredEmail)
+from rest_framework_simplejwt.serializers import TokenObtainPairSerializer
 from rest_framework import serializers
 from xtrm_drest.serializers import (
     DynamicModelSerializer,
@@ -11,6 +12,7 @@ from xtrm_drest.serializers import (
 )
 from django.contrib.auth.models import Group, Permission
 from django.contrib.contenttypes.models import ContentType
+from django.db.models.functions import Concat
 from .utils import get_author_model
 errors = {
     "already_invited": _("This e-mail address has already been"
@@ -22,6 +24,38 @@ errors = {
 
 AuthorModel = get_author_model()
 
+def getVisiblePermissions():
+    ct = ContentType.objects.all()
+    myNameList = []
+    for c in ct:
+        class_name = c.model_class()
+        if hasattr(class_name, "xtrmMeta"):
+            myNameList.append((class_name._meta.app_label +
+                               class_name.__name__).lower())
+    return myNameList
+
+class UserTokenPairSerializer(TokenObtainPairSerializer):
+    def validate(self, attrs):
+        data=super().validate(attrs)
+        myNameList = getVisiblePermissions()
+        perms = self.user.groups.first()
+        rtn = []
+        if perms:
+            for perm in perms.permissions.all().annotate(num_authors=Concat('content_type__app_label', 'content_type__model')).filter(num_authors__in=myNameList):
+                pm = {
+                    "id": perm.id,
+                    "name": perm.name,
+                    "codename": perm.codename,
+                    "app_label": perm.content_type.app_label,
+                    "model": perm.content_type.model
+                }
+                rtn.append(pm)
+        # Add custom claims
+        data['user'] = UserSerializer(self.user).data
+        data['permissions'] = rtn
+        # ...
+
+        return data
 
 class EmailListField(serializers.ListField):
     child = serializers.EmailField()
@@ -144,7 +178,7 @@ class GroupOptionsSerializer(DynamicModelSerializer):
     class Meta:
         model = GroupOptions
         fields = '__all__'
-        read_only_fields = ('is_admin')
+        read_only_fields = ('is_admin',)
 
 
 class CUserSerializer(serializers.ModelSerializer):
