@@ -11,7 +11,7 @@ def get_author_model():
     path = getattr(settings, 'INVITATIONS_AUTHOR_MODEL')
     try:
         return django_apps.get_model(path)
-        print(django_apps.get_model(path).Meta.verbose_name)
+        # print(django_apps.get_model(path).Meta.verbose_name)
     except ValueError:
         raise ImproperlyConfigured(
             "path must be of the form 'app_label.model_name'"
