@@ -13,13 +13,17 @@ from .models import GuestInvitation as InvitationModel, GroupOptions, User
 from django.contrib.auth.models import Group, Permission
 from django.contrib.contenttypes.models import ContentType
 # from .serializers import InvitationReadSerializer,InvitationBulkWriteSerializer,InvitationWriteSerializer,UserSerializer, GroupSerializer, PermissionSerializer,ContenttypeSerializer,GroupOptionsSerializer,CUserSerializer, CGroupSerializer,CGroupOptionsSerializer
-from .serializers import InvitationReadSerializer, InvitationBulkWriteSerializer, InvitationWriteSerializer, UserSerializer, GroupSerializer, PermissionSerializer, ContenttypeSerializer, GroupOptionsSerializer, CUserSerializer, CGroupSerializer
+from .serializers import InvitationReadSerializer, InvitationBulkWriteSerializer, InvitationWriteSerializer, UserSerializer, GroupSerializer, PermissionSerializer, ContenttypeSerializer, GroupOptionsSerializer, CUserSerializer, CGroupSerializer,UserTokenPairSerializer
 from rest_auth.views import LoginView as RestAuthLoginView
 from django.conf import Settings, settings
 from .utils import get_author_model
 from django.db.models.functions import Concat
+from rest_framework_simplejwt.views import TokenObtainPairView
 from django.db.models import Q
 
+class UserTokenPairView(TokenObtainPairView):
+    serializer_class = UserTokenPairSerializer
+
 AuthorModel = get_author_model()
 
 HAS_GUEST_PERMISSION = settings.ENABLE_GUEST_USER if hasattr(settings, 'ENABLE_GUEST_USER') else False
@@ -42,6 +46,7 @@ def getVisiblePermissions():
 def jwt_response_payload_handler(token, user=None, request=None):
     myNameList = getVisiblePermissions()
     perms = user.groups.first()
+    # print(**perms)
     rtn = []
     if perms:
         for perm in perms.permissions.all().annotate(num_authors=Concat('content_type__app_label', 'content_type__model')).filter(num_authors__in=myNameList):
